@@ -108,6 +108,7 @@ type ConfigFile struct {
 	// Password manager configurations.
 	AWSSecretsManager awsSecretsManagerConfig `json:"awsSecretsManager" mapstructure:"awsSecretsManager" yaml:"awsSecretsManager"` //nolint:lll
 	Bitwarden         bitwardenConfig         `json:"bitwarden" mapstructure:"bitwarden" yaml:"bitwarden"`
+	Dashlane          dashlaneConfig          `json:"dashlane" mapstructure:"dashlane" yaml:"dashlane"`
 	Gopass            gopassConfig            `json:"gopass" mapstructure:"gopass" yaml:"gopass"`
 	Keepassxc         keepassxcConfig         `json:"keepassxc" mapstructure:"keepassxc" yaml:"keepassxc"`
 	Keeper            keeperConfig            `json:"keeper" mapstructure:"keeper" yaml:"keeper"`
@@ -361,6 +362,8 @@ func newConfig(options ...configOption) (*Config, error) {
 		"bitwardenAttachmentByRef": c.bitwardenAttachmentByRefTemplateFunc,
 		"bitwardenFields":          c.bitwardenFieldsTemplateFunc,
 		"comment":                  c.commentTemplateFunc,
+		"dashlaneNote":             c.dashlaneNoteTemplateFunc,
+		"dashlanePassword":         c.dashlanePasswordTemplateFunc,
 		"decrypt":                  c.decryptTemplateFunc,
 		"deleteValueAtPath":        c.deleteValueAtPathTemplateFunc,
 		"encrypt":                  c.encryptTemplateFunc,
@@ -1827,7 +1830,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 			// Do nothing.
 		case err == nil:
 			return fmt.Errorf("%s: not a directory", c.SourceDirAbsPath)
-		case err != nil:
+		default:
 			return err
 		}
 	}
@@ -2205,9 +2208,6 @@ func (c *Config) targetRelPaths(
 		if err != nil {
 			return nil, err
 		}
-		if err != nil {
-			return nil, err
-		}
 		if options.mustBeInSourceState {
 			if !sourceState.Contains(targetRelPath) {
 				return nil, fmt.Errorf("%s: not in source state", arg)
@@ -2413,6 +2413,9 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 		Bitwarden: bitwardenConfig{
 			Command: "bw",
 		},
+		Dashlane: dashlaneConfig{
+			Command: "dcli",
+		},
 		Gopass: gopassConfig{
 			Command: "gopass",
 		},
